" 「Vimの流儀」本文中で解説されたカスタマイズ例




" 3章 P141 vimrcをリローダブルにする際の落とし穴
  " ユーザー定義のオートコマンドを全て削除する。
autocmd!

  " 誌面ではページ数の都合で触れられなかったが、
  " オートコマンドは特定のグループにまとめることができるので、
  " ユーザー定義のオートコマンド用のグループを作成しておく方が、
  " どこに何が追加されるのかやリセットするときも何がリセットされるかが
  " 明確になるので良い。
  "
  " グループの定義とそのグループ内のオートコマンドのリセットは以下の通り:
  " augroup MyAutoCmd
  "   autocmd!
  " augroup END
  "
  " グループMyAutoCmd内にオートコマンドを定義するには以下のようにする:
  " autocmd! MyAutoCmd ColorScheme *  ...
  "
  " 詳細は:help autocmd-groupsを参照。




" 2章 P127 VimをVimとして使うために最低限必要な設定
  " ファイル種類の自動判別とそれに応じた適切設定/インデントを行なう。
filetype plugin indent on
  " ファイルの種類に応じたシンタックスハイライトを有効にする。
syntax enable




" 3章 P139 vimrcを即座に編集できるようにする
nnoremap <Space>.  :<C-u>edit $MYVIMRC<Enter>

" 3章 P140 vimrcを即座にリロードできるようにする
nnoremap <Space>s.  :<C-u>source $MYVIMRC<Enter>




" 3章 P142 'backspace' - バックスペースの挙動を改善する
  " 改行文字/インデント/インサートモード開始位置より前の文字を削除可能にする。
set backspace=eol,indent,start

" 3章 P142 'ignorecase' - 検索における大文字・小文字の無視
  " /{pattern}や?{pattern}による検索で大文字・小文字の違いを無視する。
set ignorecase

" 3章 P142 'smartcase' - 検索における大文字・小文字の区別の改善
  " 検索パターンに大文字が含まれる場合は大文字・小文字を区別する。
set smartcase




" 3章 P143 :helpを引きやすくする
  " <C-h>の1キーで:helpを引く準備ができるようにする。
nnoremap <C-h>  :<C-u>help<Space>
  " <C-h><C-h>でカーソル下のキーワードを:helpで引く。
nnoremap <C-h><C-h>  :<C-u>help<Space><C-r><C-w><Enter>

" 3章 P144 Exコマンドを入力しやすくする
  " ;と:の意味を入れ替える。文字として入力する場合はそのまま。
noremap ;  :
noremap :  ;

" 3章 P145 論理行移動と表示行移動のキーバインディングを入れ替える
  " j/kを表示行単位の移動に変更する。
noremap j  gj
noremap k  gk
  " gj/gkを論理行単位の移動に変更する。
noremap gj  j
noremap gk  k

" 3章 P145 日時の入力補助
  " 2009-08-24T12:34:56のフォーマットで現在の日時を挿入する。
inoremap <expr> ,df  strftime('%Y-%m-%dT%H:%M:%S')
  " 2009-08-24のフォーマットで現在の日付を挿入する。
inoremap <expr> ,dd  strftime('%Y-%m-%d')
  " 12:34:56のフォーマットで現在の時刻を挿入する。
inoremap <expr> ,dt  strftime('%H:%M:%S')

" 3章 P146 最後に変更したテキストの選択
nnoremap gc  `[v`]
vnoremap gc  :<C-u>normal gc<Enter>
onoremap gc  :<C-u>normal gc<Enter>




" 3章 P148 シンタックスハイライトの色設定の上書き
autocmd ColorScheme *
\ highlight TabLine
\           cterm=NONE ctermfg=lightgray ctermbg=darkgray
doautocmd ColorScheme _

" 3章 P149 カレントウィンドウのカーソル行をハイライトする
autocmd WinEnter *  setlocal cursorline
autocmd WinLeave *  setlocal nocursorline




" 3章 P150 文字エンコーディングを指定してファイルを開く
  " 単純なバージョン。
  " :Utf8などとして文字エンコーディングを指定して
  " 現在開いているファイルを開きなおすことができる。
command! Cp932  edit ++enc=cp932
command! Eucjp  edit ++enc=euc-jp
command! Iso2022jp  edit ++enc=iso-2022-jp
command! Utf8  edit ++enc=utf-8

command! Jis  Iso2022jp
command! Sjis  Cp932

  " さらに:editと同様に利用できるようにしたバージョン。
  " 上記のものと比較すると、
  " :Utf8 utf8.txtなどとして文字エンコーディングを指定して
  " ファイルを開くことができる。
command! -bang -bar -complete=file -nargs=? Utf8
\ edit<bang> ++enc=utf-8 <args>
command! -bang -bar -complete=file -nargs=? Eucjp
\ edit<bang> ++enc=euc-jp <args>
command! -bang -bar -complete=file -nargs=? Iso2022jp
\ edit<bang> ++enc=iso-2022-jp <args>
command! -bang -bar -complete=file -nargs=? Cp932
\ edit<bang> ++enc=cp932 <args>

command! -bang -bar -complete=file -nargs=? Jis  Iso2022jp<bang> <args>
command! -bang -bar -complete=file -nargs=? Sjis  Cp932<bang> <args>

" 3章 P150 :cdを使いやすくする
command! -complete=customlist,CompleteCD -nargs=? CD  cd <args>
function! CompleteCD(arglead, cmdline, cursorpos)
  let pattern = join(split(a:cmdline, '\s', !0)[1:], ' ') . '*/'
  return split(globpath(&cdpath, pattern), "\n")
endfunction

" 3章 P151 標準のExコマンドを独自のもので置き換える
  " :cdを入力すると自動的に:CDが使われるようにする。
cnoreabbrev <expr> cd
\ (getcmdtype() == ':' && getcmdline() ==# 'cd') ? 'CD' : 'cd'




" 3章 P152 ファイルタイププラグイン
  " ディレクトリfiletype-plugin-sample下の内容を参照。




" 4章 P157 surroundのカスタマイズ例
nmap s  <Plug>Ysurround
nmap ss  <Plug>Yssurround

" 4章 P158 smartchrのカスタマイズ例
inoremap <expr> =  smartchr#loop(' = ', ' == ', '=')

" 4章 P159 arpeggioのカスタマイズ例
call arpeggio#load()  " vimrcに記述する場合に必要

  " aとrの同時押しで選択範囲のテキストを右寄せする。
  " 特に範囲が選択されていなければカーソル行を右寄せする。
Arpeggio nnoremap ar  :right<Enter>
Arpeggio vnoremap ar  :right<Enter>

  " 同時押しされなかった場合のaやrの動作をカスタマイズするには
  " 以下のように記述する。
" nnoremap <Plug>(arpeggio-default:a)  ...
" vnoremap <Plug>(arpeggio-default:a)  ...
" nnoremap <Plug>(arpeggio-default:r)  ...
" vnoremap <Plug>(arpeggio-default:r)  ...




" 5章 P161 プラグイン作成のいろは
  " ディレクトリplugin-sample下の内容を参照。




" __END__
